@@ -35,11 +35,11 @@
 
 #include <QDateTime>
 #include <QHostAddress>
-#include <QRegExp>
 #include <QTcpSocket>
 #include <QTimer>
 #include <QTextCodec>
 #include "noteshared_debug.h"
+#include "noteutils.h"
 #include <QLocale>
 
 // Maximum note size in chars we are going to accept,
@@ -92,8 +92,11 @@ NotesNetworkReceiver::NotesNetworkReceiver(QTcpSocket *s)
     // Setup the communications
     connect(d->m_sock, &QTcpSocket::readyRead, this, &NotesNetworkReceiver::slotDataAvailable);
     connect(d->m_sock, &QTcpSocket::disconnected, this, &NotesNetworkReceiver::slotConnectionClosed);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(d->m_sock, qOverload<QAbstractSocket::SocketError>(&QTcpSocket::error), this, &NotesNetworkReceiver::slotError);
-
+#else
+    connect(d->m_sock, qOverload<QAbstractSocket::SocketError>(&QTcpSocket::errorOccurred), this, &NotesNetworkReceiver::slotError);
+#endif
     // Setup the timer
     d->m_timer = new QTimer(this);
     d->m_timer->setSingleShot(true);
@@ -144,16 +147,11 @@ void NotesNetworkReceiver::slotConnectionClosed()
     QTextCodec *codec = QTextCodec::codecForLocale();
 
     if (d->m_timer->isActive()) {
-        QString noteText = QString(codec->toUnicode(*d->m_buffer)).trimmed();
-
-        // First line is the note title or, in case of ATnotes, the id
-        const int pos = noteText.indexOf(QRegExp(QLatin1String("[\r\n]")));
-        const QString noteTitle = noteText.left(pos).trimmed() + d->m_titleAddon;
-
-        noteText = noteText.mid(pos).trimmed();
-
-        if (!noteText.isEmpty()) {
-            Q_EMIT sigNoteReceived(noteTitle, noteText);
+        const QString noteText = QString(codec->toUnicode(*d->m_buffer)).trimmed();
+        NoteUtils utils;
+        const NoteUtils::NoteText result = utils.extractNoteText(noteText, d->m_titleAddon);
+        if (!result.noteText.isEmpty()) {
+            Q_EMIT sigNoteReceived(result.noteTitle, result.noteText);
         }
     }
 
